package net.zenrindatacom.geofenceapp_sample.activity.notification;

import android.app.AlertDialog;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

import androidx.appcompat.app.AppCompatActivity;

import net.zenrindatacom.geofenceapp_sample.R;
import net.zenrindatacom.geofenceapp_sample.activity.general.CustomAsyncTask;
import net.zenrindatacom.geofenceapp_sample.activity.general.DialogUtil;
import net.zenrindatacom.geofenceapp_sample.geofence.GeoFenceWrapperManager;

import java.util.ArrayList;
import java.util.List;

/**
 * 通知条件管理画面
 */
public class NotificationMngActivity extends AppCompatActivity {

    /** ログのTAG */
    private static final String TAG = "NotificationMngActivity";

    /**
     * onCreate
     */
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.notification_mng);
    }

    /**
     * 画面内のボタンがタップされた
     *
     * @param view タップされたアイテム
     */
    public void onClick(View view) {

        //2度押し防止
        Button button = (Button)view;
        button.setEnabled(false);
        new Handler(Looper.getMainLooper()).postDelayed(() -> button.setEnabled(true), 1000);

        int viewId = view.getId();

        if (viewId == R.id.btnAddNotification) {
            //通知条件を追加
            Intent intent = new Intent(this, NotificationAddActivity.class);
            startActivity(intent);

        } else if (viewId == R.id.btnDeleteNotification) {
            //通知条件を削除
            removeNotificationConditionInfo();

        } else if (viewId == R.id.btnGetNotification) {
            //通知条件を取得
            getNotificationConditionInfoList();
        }
    }

    /**
     * 通知条件を削除
     */
    private void removeNotificationConditionInfo() {

        //エリアIDの入力フィールド
        final EditText editTextAreaId = new EditText(this);

        //確認ダイアログの表示
        new AlertDialog.Builder(this)
                .setIcon(android.R.drawable.ic_dialog_info)
                .setTitle(R.string.dlg_title_confirm_delete_notification_condition)
                .setMessage(R.string.dlg_msg_confirm_delete_notification_condition)
                .setView(editTextAreaId)
                .setPositiveButton(R.string.dlg_btn_ok, (dialog, whichButton) -> {
                    //OKボタンをタップ

                    String inputAreaId = editTextAreaId.getText().toString();
                    Log.d(TAG, "Input Area Id=" + inputAreaId);

                    ArrayList<String> inputAreaIdList = new ArrayList<>();
                    if (inputAreaId.length() > 0) {
                        inputAreaIdList.add(inputAreaId);
                    }

                    // プログレスバーを表示
                    DialogUtil.showProgress(this, R.string.dlg_msg_progress_remove);

                    new CustomAsyncTask() {
                        @Override
                        public Object doAsyncTask() {
                            //ジオフェンスライブラリから通知条件を削除する
                            return GeoFenceWrapperManager.getGeoFenceManager().removeNotificationConditionInformation(inputAreaIdList);
                        }

                        @Override
                        public void onSuccess(Object result) {
                            // プログレスバーを消す
                            DialogUtil.hideProgress();

                            if (result != null && ((List<?>)result).size() > 0) {
                                //削除したものが存在する
                                DialogUtil.showAlert(NotificationMngActivity.this, R.string.dlg_title_alert_geofence_lib, R.string.dlg_msg_alert_geofence_lib_delete_success);
                            } else {
                                //削除したものが存在しない
                                DialogUtil.showAlert(NotificationMngActivity.this, R.string.dlg_title_alert_geofence_lib, R.string.dlg_msg_alert_geofence_lib_delete_fail);
                            }
                        }

                        @Override
                        public void onException(Exception e) {
                        }
                    }.execute();
                })
                .setNegativeButton(R.string.dlg_btn_cancel,null)
                .show();
    }

    /**
     * 通知条件を取得
     */
    private void getNotificationConditionInfoList() {

        //エリアIDの入力フィールド
        final EditText editTextNotificationConditionId = new EditText(this);

        //確認ダイアログの表示
        new AlertDialog.Builder(this)
                .setIcon(android.R.drawable.ic_dialog_info)
                .setTitle(R.string.dlg_title_confirm_get_notification_condition)
                .setMessage(R.string.dlg_msg_confirm_get_notification_condition)
                .setView(editTextNotificationConditionId)
                .setPositiveButton(R.string.dlg_btn_ok, (dialog, whichButton) -> {
                    //OKボタンをタップ

                    //通知条件が存在する場合は「通知条件表示画面」に表示
                    Intent intent = new Intent(this, NotificationListActivity.class);
                    //抽出条件
                    String inputNotificationConditionId = editTextNotificationConditionId.getText().toString();
                    Log.d(TAG, "Input Notification Condition Id=" + inputNotificationConditionId);
                    intent.putExtra(NotificationListActivity.INTENT_KEY_CONDITION, inputNotificationConditionId);

                    startActivity(intent);
                })
                .setNegativeButton(R.string.dlg_btn_cancel,null).
                show();
    }
}
