package net.zenrindatacom.geofenceapp_sample.application;

import android.annotation.SuppressLint;
import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.util.Log;

import net.zenrindatacom.geofenceapp_sample.locationlib.LocationLibConst;

/**
 * アプリケーションクラス
 */
public class SampleApplication extends Application {

    /** ログ出力用タグ */
    private static final String TAG = "SampleApplication";

    @SuppressLint("StaticFieldLeak")
    private static Context mContext;

    /** 位置測位ライブラリからの通知をキャスト通知するインタフェース */
    private ILocationNotifyListener mLocationNotifyListener;

    /**
     * 位置測位ライブラリからの通知をキャストした結果を受け取るリスナーを設定する
     *
     * @param listener リスナー
     */
    public void setLocationNotifyListener(ILocationNotifyListener listener) {
        mLocationNotifyListener = listener;
    }

    /**
     * onCreate
     */
    @Override
    public void onCreate() {
        super.onCreate();
        mContext = getApplicationContext();
    }

    /**
     * Contextを返す
     *
     * @return Context
     */
    public static Context getAppContext() {
        return mContext;
    }

    /**
     * 通知情報を設定されているリスナー用にキャストする
     *
     * @param intent NO DESCRIPTION
     */
    public void notifyInformation(final Intent intent) {

        final String information = intent.getStringExtra(LocationLibConst.KEY_INFORMATION);
        if (information == null) {
            Log.e(TAG, "Information is null.");
            return;
        }

        //=======================================================================
        // リスナー登録先へ通知する
        //=======================================================================
        if (mLocationNotifyListener == null) {
            //通知先が存在しない
            Log.i(TAG, "Listener is null.");
            return;
        }

        Log.i(TAG, "LocationLib notify : " + information);

        switch (information) {
            case LocationLibConst.INFORMATION_MEASURE:
                //測位結果Intent（連続測位）
                String result = intent.getStringExtra(LocationLibConst.KEY_RESULT);
                if (result != null) {
                    if (result.equals(LocationLibConst.RESULT_OK)) {
                        //測定結果OKパターン
                        mLocationNotifyListener.onNotifiedLocationOK(intent);
                    } else if (result.equals(LocationLibConst.RESULT_NG)) {
                        //測定結果NGパターン
                        mLocationNotifyListener.onNotifiedLocationNG(intent);
                    }
                }
                break;
            case LocationLibConst.INFORMATION_AUTH_ERROR:
                //認証エラーIntent
                mLocationNotifyListener.onNotifiedAuthError(intent);
                break;
            case LocationLibConst.INFORMATION_ERROR:
                //内部エラーIntent
                mLocationNotifyListener.onNotifiedInternalError(intent);
                break;
            case LocationLibConst.INFORMATION_OPERATION_ERROR:
                //オペレーション実行エラーIntent
                mLocationNotifyListener.onNotifiedOperationError(intent);
                break;
            default:
                break;
        }
    }
}
