package net.zenrindatacom.geofenceapp_sample.http.dto;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonSetter;
import com.fasterxml.jackson.databind.JsonNode;

import java.util.ArrayList;

/**
 * (エリア情報サーバ)エリア検索APIのレスポンスDTO
 *
 * @author N.Miyahara
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
public class SrvSearchAreaResDto {

    /**
     * レスポンス情報クラス
     */
    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonIgnoreProperties(ignoreUnknown=true)
    public static class Response {
        /**
         * 処理結果情報クラス
         */
        @SuppressWarnings("unused")
        @JsonInclude(JsonInclude.Include.NON_NULL)
        @JsonIgnoreProperties(ignoreUnknown=true)
        public static class Status {
            /** 処理結果コード */
            private int returnCode;
            public int getReturnCode() {
                return returnCode;
            }
            public void setReturnCode(int returnCode) {
                this.returnCode = returnCode;
            }

            /** エラーメッセージ */
            private String errorMessage;
            public String getErrorMessage() {
                return errorMessage;
            }
            public void setErrorMessage(String errorMessage) {
                this.errorMessage = errorMessage;
            }
        }

        /**
         * 取得結果情報クラス
         */
        @SuppressWarnings("unused")
        @JsonInclude(JsonInclude.Include.NON_NULL)
        @JsonIgnoreProperties(ignoreUnknown=true)
        public static class Result {
            /**
             * エリア情報
             */
            @JsonIgnoreProperties(ignoreUnknown=true)
            public static class Area {
                /** エリアグループID */
                private String areaGroupId;
                public String getAreaGroupId() {
                    return areaGroupId;
                }
                public void setAreaGroupId(String areaGroupId) {
                    this.areaGroupId = areaGroupId;
                }

                /** エリアID */
                private String areaId;
                public String getAreaId() {
                    return areaId;
                }
                public void setAreaId(String areaId) {
                    this.areaId = areaId;
                }

                /** エリア形状 (このプロパティ配下はJson文字列で保持する) */
                private String areaShape;
                public String getAreaShape() {
                    return areaShape;
                }
                @JsonSetter("areaShape")
                public void setAreaShape(JsonNode areaShape) {
                    this.areaShape = areaShape.toString();
                }
            }

            /** limit前件数 */
            private int limitBeforeCount;
            public int getLimitBeforeCount() {
                return limitBeforeCount;
            }
            public void setLimitBeforeCount(int limitBeforeCount) {
                this.limitBeforeCount = limitBeforeCount;
            }

            /** limit後件数 */
            private int limitAfterCount;
            public int getLimitAfterCount() {
                return limitAfterCount;
            }
            public void setLimitAfterCount(int limitAfterCount) {
                this.limitAfterCount = limitAfterCount;
            }

            /** エリア配列 */
            private ArrayList<Area> areas;
            public ArrayList<Area> getAreas() {
                return areas;
            }
            public void setAreas(ArrayList<Area> areas) {
                this.areas = areas;
            }
        }

        /** 処理結果情報 */
        private Status status;
        public Status getStatus() {
            return status;
        }
        @SuppressWarnings("unused")
        public void setStatus(Status status) {
            this.status = status;
        }

        /** 取得結果情報 */
        private Result result;
        public Result getResult() {
            return result;
        }
        @SuppressWarnings("unused")
        public void setResult(Result result) {
            this.result = result;
        }
    }

    /** レスポンス情報 */
    private Response response;
    public Response getResponse() {
        return response;
    }
    @SuppressWarnings("unused")
    public void setResponse(Response response) {
        this.response = response;
    }
}
